````json
{
	"model": "deepseek-v3-250324",
	"messages": [{
		"role": "system",
		"content": "In this environment you have access to a set of tools you can use to answer the user's question. You can use one tool per message, and will receive the result of that tool use in the user's response. You use tools step-by-step to accomplish a given task, with each tool use informed by the result of the previous tool use.\n\n## Tool Use Formatting\n\nTool use is formatted using XML-style tags. The tool name is enclosed in opening and closing tags, and each parameter is similarly enclosed within its own set of tags. Here's the structure:\n\n<tool_use>\n  <name>{tool_name}</name>\n  <arguments>{json_arguments}</arguments>\n</tool_use>\n\nThe tool name should be the exact name of the tool you are using, and the arguments should be a JSON object containing the parameters required by that tool. For example:\n<tool_use>\n  <name>python_interpreter</name>\n  <arguments>{\"code\": \"5 + 3 + 1294.678\"}</arguments>\n</tool_use>\n\nThe user will respond with the result of the tool use, which should be formatted as follows:\n\n<tool_use_result>\n  <name>{tool_name}</name>\n  <result>{result}</result>\n</tool_use_result>\n\nThe result should be a string, which can represent a file or any other output type. You can use this result as input for the next action.\nFor example, if the result of the tool use is an image file, you can use it in the next action like this:\n\n<tool_use>\n  <name>image_transformer</name>\n  <arguments>{\"image\": \"image_1.jpg\"}</arguments>\n</tool_use>\n\nAlways adhere to this format for the tool use to ensure proper parsing and execution.\n\n## Tool Use Examples\n\nHere are a few examples using notional tools:\n---\nUser: Generate an image of the oldest person in this document.\n\nAssistant: I can use the document_qa tool to find out who the oldest person is in the document.\n<tool_use>\n  <name>document_qa</name>\n  <arguments>{\"document\": \"document.pdf\", \"question\": \"Who is the oldest person mentioned?\"}</arguments>\n</tool_use>\n\nUser: <tool_use_result>\n  <name>document_qa</name>\n  <result>John Doe, a 55 year old lumberjack living in Newfoundland.</result>\n</tool_use_result>\n\nAssistant: I can use the image_generator tool to create a portrait of John Doe.\n<tool_use>\n  <name>image_generator</name>\n  <arguments>{\"prompt\": \"A portrait of John Doe, a 55-year-old man living in Canada.\"}</arguments>\n</tool_use>\n\nUser: <tool_use_result>\n  <name>image_generator</name>\n  <result>image.png</result>\n</tool_use_result>\n\nAssistant: the image is generated as image.png\n\n---\nUser: \"What is the result of the following operation: 5 + 3 + 1294.678?\"\n\nAssistant: I can use the python_interpreter tool to calculate the result of the operation.\n<tool_use>\n  <name>python_interpreter</name>\n  <arguments>{\"code\": \"5 + 3 + 1294.678\"}</arguments>\n</tool_use>\n\nUser: <tool_use_result>\n  <name>python_interpreter</name>\n  <result>1302.678</result>\n</tool_use_result>\n\nAssistant: The result of the operation is 1302.678.\n\n---\nUser: \"Which city has the highest population , Guangzhou or Shanghai?\"\n\nAssistant: I can use the search tool to find the population of Guangzhou.\n<tool_use>\n  <name>search</name>\n  <arguments>{\"query\": \"Population Guangzhou\"}</arguments>\n</tool_use>\n\nUser: <tool_use_result>\n  <name>search</name>\n  <result>Guangzhou has a population of 15 million inhabitants as of 2021.</result>\n</tool_use_result>\n\nAssistant: I can use the search tool to find the population of Shanghai.\n<tool_use>\n  <name>search</name>\n  <arguments>{\"query\": \"Population Shanghai\"}</arguments>\n</tool_use>\n\nUser: <tool_use_result>\n  <name>search</name>\n  <result>26 million (2019)</result>\n</tool_use_result>\nAssistant: The population of Shanghai is 26 million, while Guangzhou has a population of 15 million. Therefore, Shanghai has the highest population.\n\n\n## Tool Use Available Tools\nAbove example were using notional tools that might not exist for you. You only have access to these tools:\n<tools>\n\n<tool>\n  <name>fUtnnwjNicTn5zWWibZu_k</name>\n  <description>save 本地记录</description>\n  <arguments>\n    {\"type\":\"object\",\"properties\":{\"key\":{\"type\":\"string\",\"description\":\"本地记录 的 key\"},\"content\":{\"type\":\"string\",\"description\":\"本地记录 的 content\"}},\"required\":[\"key\",\"content\"],\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-07/schema#\"}\n  </arguments>\n</tool>\n\n\n<tool>\n  <name>fmfoD0fHqyUqcKHbrcSemx</name>\n  <description>get 本地记录</description>\n  <arguments>\n    {\"type\":\"object\",\"properties\":{\"key\":{\"type\":\"string\",\"description\":\"本地记录 的 key\"},\"id\":{\"type\":\"string\",\"description\":\"本地记录 的 id\"}},\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-07/schema#\"}\n  </arguments>\n</tool>\n\n\n<tool>\n  <name>fQWGJg9DOX3Y2sIJHajAbB</name>\n  <description>执行按下鼠标按钮然后立即释放的操作。\n当没有传递任何参数时，主鼠标按钮将在鼠标光标当前位置处点击。</description>\n  <arguments>\n    {\"type\":\"object\",\"properties\":{\"x\":{\"anyOf\":[{\"anyOf\":[{\"not\":{}},{\"type\":\"number\"}]},{\"type\":\"array\",\"minItems\":2,\"maxItems\":2,\"items\":[{\"type\":\"number\"},{\"type\":\"number\"}]}],\"description\":\"可选参数 x\\n如果同时传递了 x 和 y 的整数值，点击将在该 x,y 坐标处发生\\n如果 x 是由两个坐标组成的数组，这些坐标将被用于 x,y 坐标点击\"},\"y\":{\"type\":\"number\",\"description\":\"可选参数 y\\n如果同时传递了 x 和 y 的整数值，点击将在该 x,y 坐标处发生\"},\"clicks\":{\"type\":\"number\",\"description\":\"可选参数 clicks\\n默认为 1\\n表示要点击次数的整数\"},\"interval\":{\"type\":\"number\",\"description\":\"可选参数 interval\\n如果 clicks > 1 它默认为 0 表示点击之间没有暂停\\n表示每次点击之间等待多少秒的数量\"},\"button\":{\"type\":\"string\",\"enum\":[\"left\",\"middle\",\"right\",\"primary\",\"secondary\"],\"description\":\"可选参数 button\\n默认为'primary'(这是鼠标左键，除非操作系统已经设置为左撇子的用户。)\\n可以是字符串常量 'left'、'middle'、'right'、'primary'或'secondary'之一\"},\"duration\":{\"type\":\"number\",\"description\":\"可选参数 duration\\n默认为 0 即时移动\\n如果指定了 x 和 y 并且 点击不在鼠标光标的当前位置发生 表示将鼠标移动到 x,y 需要多少秒\"}},\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-07/schema#\"}\n  </arguments>\n</tool>\n\n\n<tool>\n  <name>facxybhVkQsharLPoaDC8j</name>\n  <description>在屏幕中查询图片的位置并点击其中心</description>\n  <arguments>\n    {\"type\":\"object\",\"properties\":{\"targetImagePath\":{\"type\":\"string\",\"description\":\"必填参数 targetImagePath\\n目标图片的绝对路径\"},\"confidence\":{\"type\":\"number\",\"description\":\"可选参数 confidence\\n表示从当前屏幕中查询图片的相似度\\n默认值 0.95\"}},\"required\":[\"targetImagePath\"],\"additionalProperties\":false,\"$schema\":\"http://json-schema.org/draft-07/schema#\"}\n  </arguments>\n</tool>\n\n</tools>\n\n## Tool Use Rules\nHere are the rules you should always follow to solve your task:\n1. Always use the right arguments for the tools. Never use variable names as the action arguments, use the value instead.\n2. Call a tool only when needed: do not call the search agent if you do not need information, try to solve the task yourself.\n3. If no tool call is needed, just answer the question directly.\n4. Never re-do a tool call that you previously did with the exact same parameters.\n5. For tool use, MARK SURE use XML tag format as shown in the examples above. Do not use any other format.\n\n# User Instructions\n\n\nNow Begin! If you solve the task correctly, you will receive a reward of $1,000,000.\n"
	},{
		"role": "user",
		"content": "获取本地 记录 id 是999的内容"
	}],
	"stream": true
}
```
````
